from django import forms
from .models import CustomUser
import datetime

class UserForm(forms.ModelForm):
    class Meta:
        model = CustomUser
        fields = ['nama', 'nik', 'jumlah_poin', 'password', 'tanggal_lahir', 'nomor_hp', 'email', 'url_blog', 'deskripsi_diri']
        widgets = {
            'password': forms.PasswordInput(),
            'tanggal_lahir': forms.DateInput(attrs={'type': 'date'}),
            'deskripsi_diri': forms.Textarea(attrs={'rows': 4}),
        }

    def clean_tanggal_lahir(self):
        tanggal_lahir = self.cleaned_data.get('tanggal_lahir')
        today = datetime.date.today()
        age = today.year - tanggal_lahir.year - (
            (today.month, today.day) < (tanggal_lahir.month, tanggal_lahir.day)
        )
        if age < 12:
            raise forms.ValidationError('Usia minimal harus 12 tahun.')
        return tanggal_lahir
