from django.contrib.auth.models import AbstractUser
from django.db import models
from django.core.validators import RegexValidator, MinValueValidator, MaxValueValidator

class CustomUser(AbstractUser):
    nama = models.CharField(
        max_length=255,
        validators=[RegexValidator(
            regex=r'^[a-zA-Z0-9._-]+$',
            message='Nama hanya boleh berisi huruf, angka, dan karakter (., _, -).'
        )]
    )
    nik = models.CharField(
    max_length=16,
    validators=[RegexValidator(
        regex=r'^\d{16}$',
        message='NIK harus terdiri dari 16 angka.'
    )],
    unique=True,
    # default='1234567890123456' 
    )

    jumlah_poin = models.IntegerField(
        validators=[MinValueValidator(0), MaxValueValidator(1_000_000)],
        default=0
    )
    password = models.CharField(
    max_length=255,
    validators=[RegexValidator(
        regex=r'^(?=.*[A-Za-z])(?=.*\d)(?=.*[^A-Za-z\d])[A-Za-z\d@$!%*?&^#(){}[\]:;<>,.?/~_+=|-]{8,255}$',
        message='Password harus minimal 8 karakter, mengandung huruf, angka, dan karakter spesial.'
    )]
    )

    tanggal_lahir = models.DateField()
    nomor_hp = models.CharField(
        max_length=15,
        validators=[RegexValidator(
            regex=r'^62\d{6,13}$',
            message='Nomor HP harus dimulai dengan kode negara 62 dan memiliki panjang 8-15 digit.'
        )]
    )
    email = models.EmailField(unique=True)
    url_blog = models.URLField(blank=True, null=True)
    deskripsi_diri = models.TextField(
        max_length=1000,
        validators=[RegexValidator(
            regex=r'.{5,1000}',
            message='Deskripsi diri harus memiliki panjang 5-1000 karakter.'
        )]
    )

    def is_valid_age(self):
        from datetime import date
        today = date.today()
        age = today.year - self.tanggal_lahir.year - (
            (today.month, today.day) < (self.tanggal_lahir.month, self.tanggal_lahir.day)
        )
        return age >= 12
